@@ -80,6 +80,18 @@
 #define PST_ATTACH_EMBEDDED         5
 #define PST_ATTACH_OLE              6
 
+// define flags
+#define PST_FLAG_READ			0x01
+#define PST_FLAG_UNMODIFIED		0x02
+#define PST_FLAG_SUBMIT			0x04
+#define PST_FLAG_UNSENT			0x08
+#define PST_FLAG_HAS_ATTACHMENT	0x10
+#define PST_FLAG_FROM_ME		0x20
+#define PST_FLAG_ASSOCIATED		0x40
+#define PST_FLAG_RESEND			0x80
+#define PST_FLAG_RN_PENDING		0x100
+#define PST_FLAG_NRN_PENDING	0x200
+
 
 typedef struct pst_entryid {
     int32_t u1;
@@ -748,6 +760,10 @@ typedef struct pst_item_appointment {
  *  each major mapi item type. It represents a complete mapi object.
  */
 typedef struct pst_item {
+    /** pointer to the pst_file */
+    struct pst_file        *pf;
+    /** block id that can be used to generate uid */
+    uint64_t               block_id;
     /** email mapi elements */
     pst_item_email         *email;
     /** folder mapi elements */
@@ -864,6 +880,8 @@ typedef struct pst_file {
     char*   cwd;
     /** original file name when the file was opened */
     char*   fname;
+    /** default character set for items without one */
+    char*   charset;
     /** the head and tail of the linked list of index structures */
     pst_index_ll *i_head, *i_tail;
     /** the head and tail of the top level of the descriptor tree */
@@ -902,12 +920,13 @@ typedef struct pst_file {
 
 
 /** Open a pst file.
- * @param pf   pointer to uninitialized pst_file structure. This structure
- *             will be filled in by this function.
- * @param name name of the file, suitable for fopen().
+ * @param pf       pointer to uninitialized pst_file structure. This structure
+ *                 will be filled in by this function.
+ * @param name     name of the file, suitable for fopen().
+ * @param charset  default charset for item with unspecified character sets
  * @return 0 if ok, -1 if error
  */
-int             pst_open(pst_file *pf, const char *name);
+int             pst_open(pst_file *pf, const char *name, const char *charset);
 
 
 /** Reopen the pst file after a fork
@@ -1070,6 +1089,20 @@ char*           pst_rfc2445_datetime_format_now(int buflen, char* result);
 const char*     pst_default_charset(pst_item *item, int buflen, char* result);
 
 
+/** Convert str to rfc2231 encoding of str
+ *  @param str   pointer to the mapi string of interest
+ */
+void            pst_rfc2231(pst_string *str);
+
+
+/** Convert str to rfc2047 encoding of str, possibly enclosed in quotes if it contains spaces
+ *  @param item          pointer to the containing mapi item
+ *  @param str           pointer to the mapi string of interest
+ *  @param needs_quote   true if strings containing spaces should be wrapped in quotes
+ */
+void            pst_rfc2047(pst_item *item, pst_string *str, int needs_quote);
+
+
 /** Convert str to utf8 if possible; null strings are preserved.
  * @param item  pointer to the containing mapi item
  * @param str   pointer to the mapi string of interest
